<?php

if ( ! defined( 'ABSPATH' ) ) {
	// Exit if accessed directly.
	exit;
}

if ( ! class_exists( 'Tonda_Select_Qode_Quick_View_For_WooCommerce' ) ) {
	class Tonda_Select_Qode_Quick_View_For_WooCommerce {
		private static $instance;

		public function __construct() {
			add_action( 'init', array( $this, 'init' ), 21 );
		}

		/**
		 * @return Tonda_Select_Qode_Quick_View_For_WooCommerce
		 */
		public static function get_instance() {
			if ( is_null( self::$instance ) ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		public function init() {
            // Change quick view position.
            add_filter( 'qode_quick_view_for_woocommerce_filter_button_loop_position_default_value', array( $this, 'set_default_button_loop_position' ) );
            add_filter('qode_quick_view_for_woocommerce_filter_quick_view_button_loop_position', array($this,'set_quick_view_button_loop_position'), 10, 3 );

            // Override product title.
            add_filter( 'qode_quick_view_for_woocommerce_filter_is_product_title_enabled', '__return_false' );
            add_action( 'qode_quick_view_for_woocommerce_action_product_summary', 'tonda_select_woocommerce_qode_quick_view_template_single_title', 5 );
            // Override buttons icon.
            add_filter( 'qode_quick_view_for_woocommerce_filter_svg_icon', array( $this, 'set_quick_view_button_icon' ), 10, 3 );
            // Remove product meta.
            add_filter( 'qode_quick_view_for_woocommerce_filter_is_product_meta_enabled', '__return_false', 9 );
            // Add single link button
            add_action( 'qode_quick_view_for_woocommerce_action_product_summary', 'tonda_select_woocommerce_qode_quick_view_single_link_label', 32 );
		}

        public function set_default_button_loop_position() {
            return 'shortcode';
        }

        public function set_quick_view_button_loop_position( $button_position_map, $button_position, $is_block_template ) {

            if ( 'shortcode' === $button_position && ! $is_block_template ) {
                $button_position_map[ $button_position ] = array(
                    'hook'     => array( 'tonda_select_action_woo_pl_info_on_image_hover', 'tonda_select_action_woo_pl_info_below_image', 'tonda_select_action_product_list_shortcode' ),
                    'priority' => array( 15, 3, 3 ),
                );
            }

            return $button_position_map;
        }

        public function set_quick_view_button_icon( $icon_html, $name, $class_name ) {

            if ( 'quick-view' === $name ) {
                $icon_html ='<svg ' . esc_attr( $class_name ) . ' xmlns="http://www.w3.org/2000/svg" viewBox="0 -256 1850 1850"><path d="M1694.373 683.898q-152-236-381-353 61 104 61 225 0 185-131.5 316.5t-316.5 131.5q-185 0-316.5-131.5t-131.5-316.5q0-121 61-225-229 117-381 353 133 205 333.5 326.5t434.5 121.5q234 0 434.5-121.5t333.5-326.5zm-720-384q0-20-14-34t-34-14q-125 0-214.5 89.5t-89.5 214.5q0 20 14 34t34 14q20 0 34-14t14-34q0-86 61-147t147-61q20 0 34-14t14-34zm848 384q0 34-20 69-140 230-376.5 368.5t-499.5 138.5q-263 0-499.5-139t-376.5-368q-20-35-20-69t20-69q140-229 376.5-368t499.5-139q263 0 499.5 139t376.5 368q20 35 20 69z"/></svg>';
            }

            return $icon_html;
        }
	}
}

if ( ! function_exists( 'tonda_init_quick_view_module' ) ) {
	/**
	 * Init main quick view module instance.
	 */
	function tonda_init_quick_view_module() {
        Tonda_Select_Qode_Quick_View_For_WooCommerce::get_instance();
	}

	add_action( 'init', 'tonda_init_quick_view_module', 15 );
}
