<?php

if ( ! defined( 'ABSPATH' ) ) {
	// Exit if accessed directly.
	exit;
}

if ( ! class_exists( 'Tonda_Select_Qode_Wishlist_For_WooCommerce' ) ) {
	class Tonda_Select_Qode_Wishlist_For_WooCommerce {
		private static $instance;

		public function __construct() {
            add_filter( 'qode_wishlist_for_woocommerce_filter_add_to_wishlist_behavior_default_value', array( $this, 'set_default_add_to_wishlist_behavior' ) );
            add_filter( 'qode_wishlist_for_woocommerce_filter_add_to_wishlist_loop_type_default_value', array( $this, 'set_default_add_to_wishlist_loop_type' ) );

            add_filter( 'qode_wishlist_for_woocommerce_filter_button_loop_position_default_value', array( $this, 'set_default_button_loop_position' ) );
            add_filter( 'qode_wishlist_for_woocommerce_filter_add_to_wishlist_button_loop_position', array( $this, 'set_add_to_wishlist_button_loop_position' ), 10, 3 );

            add_filter( 'qode_wishlist_for_woocommerce_filter_svg_icon', array( $this, 'set_add_to_wishlist_heart_icon' ), 10, 3 );
            add_filter( 'qode_wishlist_for_woocommerce_filter_svg_icon', array( $this, 'set_add_to_wishlist_heart_added_icon' ), 10, 3 );

            add_filter( 'qode_wishlist_for_woocommerce_filter_show_table_title_default_value', array( $this, 'disable_wishlist_page_title' ) );
            add_filter( 'qode_wishlist_for_woocommerce_filter_enable_share_default_value', array( $this, 'set_share_default_value' ) );
            add_filter( 'qode_wishlist_for_woocommerce_filter_available_table_items_default_values', array( $this, 'set_available_table_items_default_values' ) );

            add_filter( 'qode_wishlist_for_woocommerce_filter_add_to_wishlist_wrapper_classes', array( $this, 'set_add_to_wishlist_theme_class' ) );
            add_filter( 'qode_wishlist_for_woocommerce_filter_wishlist_table_holder_classes', array( $this, 'set_add_to_wishlist_theme_class' ) );
		}

		/**
		 * @return Tonda_Select_Qode_Wishlist_For_WooCommerce
		 */
		public static function get_instance() {
			if ( is_null( self::$instance ) ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		public function set_default_add_to_wishlist_behavior() {
			return 'view';
		}

		public function set_default_button_loop_position() {
			return 'shortcode';
		}

		public function set_default_add_to_wishlist_loop_type() {
			return 'icon';
		}

        public function set_add_to_wishlist_button_loop_position( $button_position_map, $button_position, $is_block_template ) {

            if ( 'shortcode' === $button_position && ! $is_block_template ) {
                $button_position_map[ $button_position ] = array(
                    'hook'     => array( 'tonda_select_action_woo_pl_info_on_image_hover', 'tonda_select_action_woo_pl_info_below_image', 'tonda_select_action_product_list_shortcode' ),
                    'priority' => array( 16, 4, 4 ),
                );
            }

            return $button_position_map;
        }

        public function set_add_to_wishlist_heart_icon( $icon_html, $name, $class_name ) {

            if ( 'heart' === $name ) {
                $icon_html = '<svg ' . esc_attr( $class_name ) . ' xmlns="http://www.w3.org/2000/svg" viewBox="0 -256 1850 1850"><path d="M1664 940q0 81-21.5 143t-55 98.5Q1554 1218 1506 1241t-94 31q-46 8-98 8t-112-25.5q-60-25.5-110.5-64t-86.5-72q-36-33.5-60-61.5-18-22-49-22t-49 22q-24 28-60 61.5t-86.5 72q-50.5 38.5-110.5 64T478 1280q-52 0-98-8t-94-31q-48-23-81.5-59.5t-55-98.5Q128 1021 128 940q0-168 187-355L896 25l580 559q188 188 188 356zm128 0q0-221-229-450L940-110q-18-18-44-18t-44 18L228 492q-10 8-27.5 26T145 583.5Q107 631 77 681T23.5 802Q0 873 0 940q0 220 127 344t351 124q62 0 126.5-21.5t120-58Q780 1292 820 1260t76-68q36 36 76 68t95.5 68.5q55.5 36.5 120 58T1314 1408q224 0 351-124t127-344z" transform="matrix(1 0 0 -1 22.78 1328.237)"/></svg>';
            }

            return $icon_html;
        }

        public function set_add_to_wishlist_heart_added_icon( $icon_html, $name, $class_name ) {

            if ( 'heart-o' === $name ) {
                $icon_html = '<svg ' . esc_attr( $class_name ) . ' xmlns="http://www.w3.org/2000/svg" viewBox="0 -256 1850 1850"><path d="M933.966 1471.424q-26 0-44-18l-624-602q-10-8-27.5-26t-55.5-65.5q-38-47.5-68-97.5t-53.5-121q-23.5-71-23.5-138 0-220 127-344t351-124q62 0 126.5 21.5t120 58q55.5 36.5 95.5 68.5t76 68q36-36 76-68t95.5-68.5q55.5-36.5 120-58t126.5-21.5q224 0 351 124t127 344q0 221-229 450l-623 600q-18 18-44 18"/></svg>';
            }

            return $icon_html;
        }

        public function set_share_default_value() {
            return 'no';
        }

        public function disable_wishlist_page_title() {
            return 'no';
        }

        public function set_available_table_items_default_values( $values ) {
            if ( ! empty( $values ) && in_array( 'category', $values, true ) ) {
                unset( $values[ array_search( 'category', $values, true ) ] );
            }
            return $values;
        }

        public function set_add_to_wishlist_theme_class( $classes ) {
            $classes[] = 'qodef-tonda-theme';

            return $classes;
        }
	}

    Tonda_Select_Qode_Wishlist_For_WooCommerce::get_instance();
}
