<?php
class ElementorQodefProductBanner extends \Elementor\Widget_Base {

	public function get_name() {
		return 'qodef_product_banner'; 
	}

	public function get_title() {
		return esc_html__( 'Product Banner', 'tonda-core' );
	}

	public function get_icon() {
		return 'tonda-elementor-custom-icon tonda-elementor-product-banner';
	}

	public function get_categories() {
		return [ 'select' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'tonda-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'product_id',
			[
				'label'     => esc_html__( 'Selected Product', 'tonda-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'If you left this field empty then product ID will be of the current page', 'tonda-core' )
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'     => esc_html__( 'Title Tag', 'tonda-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'description' => esc_html__( 'Set title tag for product title element', 'tonda-core' ),
				'options' => array(
					'' => esc_html__( 'Default', 'tonda-core'), 
					'h1' => esc_html__( 'h1', 'tonda-core'), 
					'h2' => esc_html__( 'h2', 'tonda-core'), 
					'h3' => esc_html__( 'h3', 'tonda-core'), 
					'h4' => esc_html__( 'h4', 'tonda-core'), 
					'h5' => esc_html__( 'h5', 'tonda-core'), 
					'h6' => esc_html__( 'h6', 'tonda-core'), 
					'p' => esc_html__( 'p', 'tonda-core')
				),
				'default' => 'h2'
			]
		);

		$this->add_control(
			'title_break_words',
			[
				'label'     => esc_html__( 'Position of Line Breaks', 'tonda-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter the positions of the words after which you would like to create a line break (e.g. if you would like the line break after first, third, and fourth word , you would enter &quot;1,3,4&quot;)', 'tonda-core' )
			]
		);

		$this->add_control(
			'featured_image_size',
			[
				'label'     => esc_html__( 'Featured Image Proportions', 'tonda-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'' => esc_html__( 'Default', 'tonda-core'), 
					'full' => esc_html__( 'Original', 'tonda-core'), 
					'tonda_select_image_square' => esc_html__( 'Square', 'tonda-core'), 
					'tonda_select_image_landscape' => esc_html__( 'Landscape', 'tonda-core'), 
					'tonda_select_image_portrait' => esc_html__( 'Portrait', 'tonda-core'), 
					'custom' => esc_html__( 'Custom', 'tonda-core')
				),
				'default' => 'full'
			]
		);

		$this->add_control(
			'featured_custom_image_width',
			[
				'label'     => esc_html__( 'Custom Featured Image Width', 'tonda-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter Featured image width in px', 'tonda-core' ),
				'condition' => [
					'featured_image_size' => array( 'custom' )
				]
			]
		);

		$this->add_control(
			'featured_custom_image_height',
			[
				'label'     => esc_html__( 'Custom Featured Image Height', 'tonda-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter Featured image height in px', 'tonda-core' ),
				'condition' => [
					'featured_image_size' => array( 'custom' )
				]
			]
		);

		$this->add_control(
			'skin',
			[
				'label'     => esc_html__( 'Skin', 'tonda-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'' => esc_html__( 'Default', 'tonda-core'), 
					'dark' => esc_html__( 'Dark', 'tonda-core')
				),
				'default' => ''
			]
		);


		$this->end_controls_section();
	}
	public function render() {

		$params = $this->get_settings_for_display();



	    $params['product_id']          = ! empty( $params['product_id'] ) ? $params['product_id'] : get_the_ID();
	    $params['title_tag']           = ! empty( $params['title_tag'] ) ? $params['title_tag'] : 'h2';
	    $params['featured_image_size'] = ! empty( $params['featured_image_size'] ) ? $params['featured_image_size'] : 'full';
        $params['skin']                = ! empty( $params['skin'] ) &&  in_array( $params['skin'], array( 'dark' ) ) ? $params['skin'] : '';

        $classes = array('qodef-product-banner');
        if (! empty( $params['skin'] )) {
            $classes[] = 'qodef-product-banner-' . $params['skin'];
        }

	    $product = wc_get_product( $params['product_id'] );

        $product_params = array(
            'product_id'                   => $params['product_id'],
            'categories'                   => wp_get_post_terms( $params['product_id'], 'product_cat' ),
            'title'                        => get_the_title( $params['product_id'] ),
            'title_break_words'            => $params['title_break_words'],
            'title_tag'                    => $params['title_tag'],
            'featured_image_size'          => $params['featured_image_size'],
            'featured_custom_image_width'  => tonda_select_filter_px( $params['featured_custom_image_width'] ),
            'featured_custom_image_height' => tonda_select_filter_px( $params['featured_custom_image_height'] ),
            'price'                        => ! empty( $product ) ? $product->get_price_html() : '',
            'classes'                      => $classes
        );

	    $product_params['title'] = $this->getModifiedTitle( $product_params );

		echo tonda_select_get_woo_shortcode_module_template_part( 'templates/product-banner-template', 'product-banner', '', $product_params );
	}

	private function getModifiedTitle( $params ) {
		$title             = $params['title'];
		$title_break_words = str_replace( ' ', '', $params['title_break_words'] );

		if ( ! empty( $title ) ) {
			$split_title = explode( ' ', $title );
			$break_words = explode( ',', $title_break_words );
			$end_string  = count( $split_title );

			if ( ! empty( $title_break_words ) ) {
				foreach ( $break_words as $value ) {
					if ( ! empty( $split_title[ $value - 1 ] ) ) {
						$split_title[ $value - 1 ] = $split_title[ $value - 1 ] . '<br />';
					}
				}
			}

			$title = implode( ' ', $split_title );
		}

		return $title;
	}

	public function productIdAutocompleteSuggester( $query ) {
		global $wpdb;
		$product_id = (int) $query;
		$post_meta_infos = $wpdb->get_results( $wpdb->prepare( "SELECT ID AS id, post_title AS title
					FROM {$wpdb->posts} 
					WHERE post_type = 'product' AND ( ID = '%d' OR post_title LIKE '%%%s%%' )", $product_id > 0 ? $product_id : - 1, stripslashes( $query ), stripslashes( $query ) ), ARRAY_A );

		$results = array();
		if ( is_array( $post_meta_infos ) && ! empty( $post_meta_infos ) ) {
			foreach ( $post_meta_infos as $value ) {
				$data = array();
				$data['value'] = $value['id'];
				$data['label'] = esc_html__( 'Id', 'tonda' ) . ': ' . $value['id'] . ( ( strlen( $value['title'] ) > 0 ) ? ' - ' . esc_html__( 'Title', 'tonda' ) . ': ' . $value['title'] : '' );
				$results[] = $data;
			}
		}

		return $results;

	}

	public function productIdAutocompleteRender( $query ) {
		$query = trim( $query['value'] ); // get value from requested
		if ( ! empty( $query ) ) {
			
			$product = get_post( (int) $query );
			if ( ! is_wp_error( $product ) ) {
				
				$product_id = $product->ID;
				$product_title = $product->post_title;
				
				$product_title_display = '';
				if ( ! empty( $product_title ) ) {
					$product_title_display = ' - ' . esc_html__( 'Title', 'tonda' ) . ': ' . $product_title;
				}
				
				$product_id_display = esc_html__( 'Id', 'tonda' ) . ': ' . $product_id;

				$data          = array();
				$data['value'] = $product_id;
				$data['label'] = $product_id_display . $product_title_display;

				return ! empty( $data ) ? $data : false;
			}

			return false;
		}

		return false;
	}

}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ElementorQodefProductBanner() );