<?php
class ElementorQodefProductCategoryList extends \Elementor\Widget_Base {

	public function get_name() {
		return 'qodef_product_category_list'; 
	}

	public function get_title() {
		return esc_html__( 'Product Category List', 'tonda-core' );
	}

	public function get_icon() {
		return 'tonda-elementor-custom-icon tonda-elementor-product-category-list';
	}

	public function get_categories() {
		return [ 'select' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'tonda-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'type',
			[
				'label'     => esc_html__( 'Type', 'tonda-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'standard' => esc_html__( 'Standard', 'tonda-core'), 
					'masonry' => esc_html__( 'Masonry', 'tonda-core')
				),
				'default' => 'standard'
			]
		);

		$this->add_control(
			'number_of_posts',
			[
				'label'     => esc_html__( 'Number of Product Categories', 'tonda-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT
			]
		);

		$this->add_control(
			'number_of_columns',
			[
				'label'     => esc_html__( 'Number of Columns', 'tonda-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'1' => esc_html__( 'One', 'tonda-core'), 
					'2' => esc_html__( 'Two', 'tonda-core'), 
					'3' => esc_html__( 'Three', 'tonda-core'), 
					'4' => esc_html__( 'Four', 'tonda-core'), 
					'5' => esc_html__( 'Five', 'tonda-core'), 
					'6' => esc_html__( 'Six', 'tonda-core')
				),
				'default' => '4'
			]
		);

		$this->add_control(
			'space_between_items',
			[
				'label'     => esc_html__( 'Space Between Items', 'tonda-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'large' => esc_html__( 'Large', 'tonda-core'), 
					'medium' => esc_html__( 'Medium', 'tonda-core'), 
					'normal' => esc_html__( 'Normal', 'tonda-core'), 
					'small' => esc_html__( 'Small', 'tonda-core'), 
					'tiny' => esc_html__( 'Tiny', 'tonda-core'), 
					'no' => esc_html__( 'No', 'tonda-core')
				),
				'default' => 'normal'
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'     => esc_html__( 'Order By', 'tonda-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'date' => esc_html__( 'Date', 'tonda-core'), 
					'ID' => esc_html__( 'ID', 'tonda-core'), 
					'menu_order' => esc_html__( 'Menu Order', 'tonda-core'), 
					'name' => esc_html__( 'Post Name', 'tonda-core'), 
					'rand' => esc_html__( 'Random', 'tonda-core'), 
					'title' => esc_html__( 'Title', 'tonda-core'), 
					'on-sale' => esc_html__( 'On Sale', 'tonda-core')
				),
				'default' => 'date'
			]
		);

		$this->add_control(
			'order',
			[
				'label'     => esc_html__( 'Order', 'tonda-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'ASC' => esc_html__( 'ASC', 'tonda-core'), 
					'DESC' => esc_html__( 'DESC', 'tonda-core')
				),
				'default' => 'ASC'
			]
		);

		$this->add_control(
			'category_slugs',
			[
				'label'     => esc_html__( 'Slugs', 'tonda-core' ),
				'description'     => esc_html__( 'Enter the category slugs you want to display, separated by commas (leave empty for showing all categories)', 'tonda-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT
			]
		);

		$this->add_control(
			'image_size',
			[
				'label'     => esc_html__( 'Image Proportions', 'tonda-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'' => esc_html__( 'Default', 'tonda-core'), 
					'full' => esc_html__( 'Original', 'tonda-core'), 
					'tonda_select_image_square' => esc_html__( 'Square', 'tonda-core'), 
					'tonda_select_image_landscape' => esc_html__( 'Landscape', 'tonda-core'), 
					'tonda_select_image_portrait' => esc_html__( 'Portrait', 'tonda-core'), 
					'medium' => esc_html__( 'Medium', 'tonda-core'), 
					'large' => esc_html__( 'Large', 'tonda-core'), 
					'woocommerce_single' => esc_html__( 'Shop Single', 'tonda-core'), 
					'woocommerce_thumbnail' => esc_html__( 'Shop Thumbnail', 'tonda-core')
				),
				'default' => 'full',
				'condition' => [
					'type' => array( 'standard' )
				]
			]
		);


		$this->end_controls_section();
	}
	public function render() {
        $default_atts = array(
            'type'                       => 'standard',
            'number_of_posts'            => '8',
            'number_of_columns'          => '4',
            'space_between_items'        => 'normal',
            'orderby'                    => 'date',
            'order'                      => 'ASC',
            'category_slugs'             => '',
            'image_size'                 => 'full'
        );

        $params       = shortcode_atts( $default_atts, $this->get_settings_for_display() );

        $params['category_slugs'] = trim( $params['category_slugs'] );
        if ( empty( $params['category_slugs'] ) ) {
            $params['category_slugs'] = array();
        } else {
            $params['category_slugs'] = explode( ',', str_replace( ' ', '', $params['category_slugs'] ) );
        }

        $additional_params                   = array();
        $additional_params['holder_classes'] = $this->getHolderClasses( $params, $default_atts );
        $additional_params['query_result']   = $this->generateProductCategoryQueryArray( $params );

        $params['this_object'] = $this;
		
		$html = tonda_select_get_woo_shortcode_module_template_part( 'templates/product-category-list', 'product-category-list', '', $params, $additional_params );
		
		echo $html;
	}

	private function getHolderClasses( $params, $default_atts ) {
		$holderClasses   = array();
		$holderClasses[] = ! empty( $params['type'] ) ? 'qodef-' . $params['type'] . '-layout' : 'qodef-' . $default_atts['type'] . '-layout';
		$holderClasses[] = ! empty( $params['space_between_items'] ) ? 'qodef-' . $params['space_between_items'] . '-space' : 'qodef-' . $default_atts['space_between_items'] . '-space';
		$holderClasses[] = $this->getColumnNumberClass( $params );

		return implode( ' ', $holderClasses );
	}

	private function getColumnNumberClass( $params ) {
		$columnsNumber = '';
		$columns       = $params['number_of_columns'];
		
		switch ( $columns ) {
			case 1:
				$columnsNumber = 'qodef-one-column';
				break;
			case 2:
				$columnsNumber = 'qodef-two-columns';
				break;
			case 3:
				$columnsNumber = 'qodef-three-columns';
				break;
			case 4:
				$columnsNumber = 'qodef-four-columns';
				break;
			case 5:
				$columnsNumber = 'qodef-five-columns';
				break;
			case 6:
				$columnsNumber = 'qodef-six-columns';
				break;
			default:
				$columnsNumber = 'qodef-four-columns';
				break;
		}
		
		return $columnsNumber;
	}

	private function generateProductCategoryQueryArray( $params ) {
		$queryArray = get_terms( array(
			'taxonomy'   => 'product_cat',
			'number'     => $params['number_of_posts'],
			'orderby'    => $params['orderby'],
			'order'      => $params['order'],
			'slug'       => $params['category_slugs'],
			'hide_empty' => false
		) );
		
		return $queryArray;
	}

}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ElementorQodefProductCategoryList() );